@@ -106,12 +106,12 @@ main (int argc, char *argv[])
       fprintf (stderr, "***         %s [-c] [-l] [-n]\n\n", argv[0]);
       fprintf (stderr, "*** Meaning of the options:\n");
       fprintf (stderr,
-	       "    -v      return the current version of the HPA library\n");
+	       "    -v      returns the current version of the HPA library,\n");
       fprintf (stderr,
-	       "    -c      return flags to compile using HPA library\n");
+	       "    -c      returns the flags to compile with HPA library,\n");
       fprintf (stderr,
-	       "    -l      return flags to link  against HPA library\n");
-      fprintf (stderr, "    -n      insert a newline at the end\n\n");
+	       "    -l      returns the flags to link against HPA library,\n");
+      fprintf (stderr, "    -n      adds a newline at the end of the output.\n\n");
       library_desc ();
       return 0;
     }
