@@ -57,7 +57,7 @@ xadd (struct xpr s, struct xpr t, int f)
     }
   else if (u)
     {
-      for (pc = pa, pf = pb; *++pc == *++pf && f < XDIM; ++f);
+      for (pc = pa, pf = pb; *(++pc) == *(++pf) && f < XDIM; ++f);
       if (f >= XDIM)
 	return xZero;
       if (*pc < *pf)
@@ -77,14 +77,17 @@ xadd (struct xpr s, struct xpr t, int f)
     }
   for (pc = pe + XDIM, pa += XDIM, pb += XDIM; pc > pf;)
     {
-      n += *pa--;
-      n += *pb--;
-      *pc-- = n;
+      n += *pa;
+      pa--;
+      n += *pb;
+      pb--;
+      *pc = n;
+      pc--;
       n >>= 16;
     }
   if (u)
     {
-      for (; *++pc == 0; ++f);
+      for (; *(++pc) == 0; ++f);
       for (k = 0; !((*pc << k) & xM_sgn); ++k);
       if ((k += 16 * f))
 	{
@@ -100,7 +103,8 @@ xadd (struct xpr s, struct xpr t, int f)
 	  ++e;
 	  if ((xsigerr (e == (short) xM_exp, XFPOFLOW, NULL)))
 	    return (!h ? xPinf : xMinf);
-	  xrshift (1, ++pf, XDIM);
+	  ++pf;
+	  xrshift (1, pf, XDIM);
 	  *pf |= xM_sgn;
 	}
     }
