@@ -93,3 +93,32 @@ xacos (struct xpr z)
 	return u;
     }
 }
+
+/* Kindly added by A.Haumer 2010-04.09 */
+
+struct xpr
+xatan2 (struct xpr y, struct xpr x)
+{
+  int rs, is;
+
+  rs = xsgn (&x);
+  is = xsgn (&y);
+  if (rs > 0)
+    return xatan (xdiv (y, x));
+  else if (rs < 0)
+    {
+      x.nmm[0] ^= xM_sgn;
+      y.nmm[0] ^= xM_sgn;
+      if (is >= 0)
+	return xadd (xPi, xatan (xdiv (y, x)), 0);
+      else
+	return xadd (xatan (xdiv (y, x)), xPi, 1);
+    }
+  else				/* x is zero ! */
+    {
+      if (!xsigerr (is == 0, XEDOM, "xatan2()"))
+	return (is > 0 ? xPi2 : xneg (xPi2));
+      else
+	return xZero;	        /* Dummy value :) */
+    }
+}
