@@ -100,6 +100,23 @@ inttox (long n)
   for (e = 0; e <= XDIM; pe[e++] = 0);
   if (n == 0)
     return *(struct xpr *) pe;
+
+#if (XULONG_BITSIZE == 64)
+
+#ifdef XLITTLE_ENDIAN
+  pe[1] = *(pc + 3);
+  pe[2] = *(pc + 2);
+  pe[3] = *(pc + 1);
+  pe[4] = *pc;
+#else
+  pe[1] = *pc;
+  pe[2] = *(pc + 1);
+  pe[3] = *(pc + 2);
+  pe[4] = *(pc + 3);
+#endif
+
+#else /* (XULONG_BITSIZE == 32) */
+
 #ifdef XLITTLE_ENDIAN
   pe[1] = *(pc + 1);
   pe[2] = *pc;
@@ -107,13 +124,16 @@ inttox (long n)
   pe[1] = *pc;
   pe[2] = *(pc + 1);
 #endif
-  for (e = 0, h = 1; h <= k && e < 31; h <<= 1, ++e);
+
+#endif
+
+  for (e = 0, h = 1; h <= k && e < (XULONG_BITSIZE-1); h <<= 1, ++e);
   if (h <= k)
     e += 1;
   *pe = xBias + e - 1;
   if (n < 0)
     *pe |= xM_sgn;
-  xlshift (32 - e, pe + 1, XDIM);
+  xlshift (XULONG_BITSIZE - e, pe + 1, XDIM);
   return *(struct xpr *) pe;
 }
 
@@ -128,6 +148,23 @@ uinttox (unsigned long n)
   for (e = 0; e <= XDIM; pe[e++] = 0);
   if (n == 0)
     return *(struct xpr *) pe;
+
+#if (XULONG_BITSIZE == 64)
+
+#ifdef XLITTLE_ENDIAN
+  pe[1] = *(pc + 3);
+  pe[2] = *(pc + 2);
+  pe[3] = *(pc + 1);
+  pe[4] = *pc;
+#else
+  pe[1] = *pc;
+  pe[2] = *(pc + 1);
+  pe[3] = *(pc + 2);
+  pe[4] = *(pc + 3);
+#endif
+
+#else /* (XULONG_BITSIZE == 32) */
+
 #ifdef XLITTLE_ENDIAN
   pe[1] = *(pc + 1);
   pe[2] = *pc;
@@ -135,10 +172,13 @@ uinttox (unsigned long n)
   pe[1] = *pc;
   pe[2] = *(pc + 1);
 #endif
-  for (e = 0, h = 1; h <= n && e < 31; h <<= 1, ++e);
+
+#endif
+
+  for (e = 0, h = 1; h <= n && e < (XULONG_BITSIZE-1); h <<= 1, ++e);
   if (h <= n)
     e += 1;
   *pe = xBias + e - 1;
-  xlshift (32 - e, pe + 1, XDIM);
+  xlshift (XULONG_BITSIZE - e, pe + 1, XDIM);
   return *(struct xpr *) pe;
 }
