@@ -22,7 +22,10 @@
 
 #include "xpre.h"
 
-static struct xpr ctan (struct xpr u);
+/*
+  renamed ctan to c_tan, suggested on 2010-04-09 by A.Haumer
+*/
+static struct xpr c_tan (struct xpr u);
 static struct xpr rred (struct xpr u, int i, int *p);
 
 /* Added by Ivano Primi - 01/30/2005 */
@@ -62,9 +65,9 @@ xtan (struct xpr z)
       else
 	m = 0;
       if ((k))
-	z = xneg (ctan (z));
+	z = xneg (c_tan (z));
       else
-	z = ctan (z);
+	z = c_tan (z);
       if (m)
 	return xdiv (xOne, z);
       else
@@ -85,7 +88,7 @@ xcos (struct xpr z)
       else
 	return xOne;
     }
-  z = ctan (xpr2 (z, -1));
+  z = c_tan (xpr2 (z, -1));
   z = xmul (z, z);
   z = xdiv (xadd (xOne, z, 1), xadd (xOne, z, 0));
   if ((k))
@@ -102,7 +105,7 @@ xsin (struct xpr z)
   z = rred (z, 's', &k);
   if (x_exp (&z) >= xK_lin)
     {
-      z = ctan (xpr2 (z, -1));
+      z = c_tan (xpr2 (z, -1));
       z = xdiv (xpr2 (z, 1), xadd (xOne, xmul (z, z), 0));
     }
   if ((k))
@@ -112,7 +115,7 @@ xsin (struct xpr z)
 }
 
 static struct xpr
-ctan (struct xpr z)
+c_tan (struct xpr z)
 {
   struct xpr s, f, d;
   int m;
