@@ -34,7 +34,7 @@
 #define DECD 32
 
 int
-getline (char *buffer, int size, FILE * fp)
+get_line (char *buffer, int size, FILE * fp)
 {
   if ((fgets (buffer, size, fp)))
     {
@@ -77,7 +77,7 @@ main (int na, char **av)
   for (i = 0; nlist[i] != NULL; i++)
     {
       printf ("\nTest of %s\n", nlist[i]);
-      while (getline (num, 1024, fp) != -1)
+      while (get_line (num, 1024, fp) != -1)
 	{
 	  printf ("*string in : \t%s\n", num);
 	  /* convert ascii string to extended precision complex */
