@@ -34,7 +34,7 @@
 #define DECD 32
 
 int
-getline (char *buffer, int size, FILE * fp)
+get_line (char *buffer, int size, FILE * fp)
 {
   if ((fgets (buffer, size, fp)))
     {
@@ -67,7 +67,7 @@ main (int na, char **av)
   fp = fopen (*++av, "r");
   /* Test of cxpwr() */
   printf ("\nTest of cxpwr()\n");
-  while (getline (num, 1024, fp) != -1)
+  while (get_line (num, 1024, fp) != -1)
     {
       printf ("*string in : \t%s\n", num);
       /* convert ascii string to extended precision complex */
@@ -110,7 +110,7 @@ main (int na, char **av)
   rewind (fp);
   /* Test of cxroot() */
   printf ("\nTest of cxroot()\n");
-  while (getline (num, 1024, fp) != -1)
+  while (get_line (num, 1024, fp) != -1)
     {
       printf ("*string in : \t%s\n", num);
       /* convert ascii string to extended precision complex */
