@@ -42,7 +42,7 @@ isNaN (const struct cxpr* z)
 }
 
 int
-getline (char *buffer, int size, FILE * fp)
+get_line (char *buffer, int size, FILE * fp)
 {
   if ((fgets (buffer, size, fp)))
     {
@@ -71,7 +71,7 @@ main (int na, char **av)
       exit (-1);
     }
   fp = fopen (*++av, "r");
-  while (getline (num, 256, fp) != -1)
+  while (get_line (num, 256, fp) != -1)
     {
       printf ("*string in : \"%s\"\n", num);
 
